@@ -31,6 +31,21 @@ void ${obj.prefix}_svc_post_init_handler(void)
  */
 ${"mrt_status_t {0}_{1}_handler(mrt_gatt_evt_t* event)".format(obj.prefix,char.name.lower())}
 {
+
+    //${t.cTypeDict[char.type]}* ptrVal = (${t.cTypeDict[char.type]}*) event->mData.data; /* Cast pointer to correct data type*/
+
+% if char.isEnum> 0:
+/*  switch(*ptrVal)
+    {
+    % for val in char.vals:
+        case ${t.padAfter(obj.prefix +"_"+char.name + "_"+val.name+":" , 45).upper()}  /* ${val.desc} */
+            break;
+    % endfor
+        default: 
+            break;
+    }/*
+
+%endif
     //TODO Handle ${char.name} Characteristic events
     return MRT_STATUS_OK;
 }
